/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.apache.beam.learning.katas.coretransforms.combine.binarycombinefn

import org.apache.beam.learning.katas.util.Log
import org.apache.beam.sdk.Pipeline
import org.apache.beam.sdk.options.PipelineOptionsFactory
import org.apache.beam.sdk.transforms.Combine
import org.apache.beam.sdk.transforms.Combine.BinaryCombineFn
import org.apache.beam.sdk.transforms.Create
import org.apache.beam.sdk.values.PCollection
import java.math.BigInteger

object Task {
  @JvmStatic
  fun main(args: Array<String>) {
    val options = PipelineOptionsFactory.fromArgs(*args).create()
    val pipeline = Pipeline.create(options)

    val numbers = pipeline.apply(
      Create.of(
        BigInteger.valueOf(10), BigInteger.valueOf(20), BigInteger.valueOf(30),
        BigInteger.valueOf(40), BigInteger.valueOf(50)
      )
    )

    val output = applyTransform(numbers)

    output.apply(Log.ofElements())

    pipeline.run()
  }

  @JvmStatic
  fun applyTransform(input: PCollection<BigInteger>): PCollection<BigInteger> {
    return input.apply(Combine.globally(SumBigIntegerFn()))
  }

  internal class SumBigIntegerFn : BinaryCombineFn<BigInteger>() {
    override fun apply(left: BigInteger, right: BigInteger): BigInteger {
      return left.add(right)
    }
  }
}